@@ -84,6 +84,19 @@ impl Clippet {
 	pub fn get_data(&self, index: usize) -> BytesMut {
 		return self.data[index].to_owned()
 	}
+	/// Takes an indexed byte sequence and returns it as a String.
+	/// ```no_run
+	/// let bytes = BytesMut::from("Hello, world!");
+	/// let mut data = Clippet { ... };
+	/// data.add_bytes(bytes);
+	/// assert_eq!(data.get_as_string(0), "Hello, world!");
+	/// ```
+	pub fn get_as_string(&self, index: usize) -> String {
+		let bytes = self.get_data(index);
+		let y = bytes.as_ref();
+		let x = String::from_utf8_lossy(y).to_string();
+		return x
+	}
 	/// Takes a filename and splits it into sequences of bytes within a Clippet.
 	/// It is recommended to use smaller byte sequences, however this is user-configurable.
 	///
